==> libreboot-25.06_src.tar.xz: libreboot-25.06_src/src/coreboot/default/Documentation/releases/coreboot-25.06-relnotes.md <==
Upcoming release - coreboot 25.06
========================================================================

The 25.06 release is scheduled for the end of June, 2025


Update this document with changes that should be in the release notes.

* Please use Markdown.
* See the past few release notes for the general format.
* The chip and board additions and removals will be updated right
  before the release, so those do not need to be added.
* Note that all changes before the release are done are marked upcoming.
  A final version of the notes are done after the release.



Significant or interesting changes
----------------------------------

* Add changes that need a full description here

* This section should have full descriptions and can or should have
  a link to the referenced commits.



Additional coreboot changes
---------------------------

The following are changes across a number of patches, or changes worth
noting, but not needing a full description.

* Changes that only need a line or two of description go here.



Changes to external resources
-----------------------------

### Toolchain updates



### Git submodule pointers


### External payloads



Platform Updates
----------------

### Added mainboards:
* To be filled in immediately before the release by the release team


### Removed Mainboards
* To be filled in immediately before the release by the release team


### Updated SoCs
* To be filled in immediately before the release by the release team



Plans to move platform support to a branch
------------------------------------------
* To be filled in immediately before the release by the release team



Statistics from the 24.12 to the 25.03 release
--------------------------------------------
* To be filled in immediately before the release by the release team



Significant Known and Open Issues
---------------------------------

Issues from the coreboot bugtracker: <https://ticket.coreboot.org/>
* To be filled in immediately before the release by the release team



coreboot Links and Contact Information
--------------------------------------

* Main Web site: <https://www.coreboot.org>
* Downloads: <https://coreboot.org/downloads.html>
* Source control: <https://review.coreboot.org>
* Documentation: <https://doc.coreboot.org>
* Issue tracker: <https://ticket.coreboot.org/projects/coreboot>
* Donations: <https://coreboot.org/donate.html>

==> libreboot-26.01rc1_src.tar.xz: libreboot-26.01rc1_src/src/coreboot/default/Documentation/releases/coreboot-26.03-relnotes.md <==
Upcoming release - coreboot 26.03
========================================================================

The 26.03 release is scheduled for the end of March, 2026


Update this document with changes that should be in the release notes.

* Please use Markdown.
* See the past few release notes for the general format.
* The chip and board additions and removals will be updated right
  before the release, so those do not need to be added.
* Note that all changes before the release are done are marked upcoming.
  A final version of the notes are done after the release.



Significant or interesting changes
----------------------------------

* Add changes that need a full description here

* This section should have full descriptions and can or should have
  a link to the referenced commits.



Additional coreboot changes
---------------------------

The following are changes across a number of patches, or changes worth
noting, but not needing a full description.

* Changes that only need a line or two of description go here.



Changes to external resources
-----------------------------

### Toolchain updates



### Git submodule pointers


### External payloads



Platform Updates
----------------

### Added mainboards:
* To be filled in immediately before the release by the release team


### Removed Mainboards
* To be filled in immediately before the release by the release team


### Updated SoCs
* To be filled in immediately before the release by the release team



Plans to move platform support to a branch
------------------------------------------
* To be filled in immediately before the release by the release team



Statistics from the 25.12 to the 26.03 release
--------------------------------------------
* To be filled in immediately before the release by the release team



Significant Known and Open Issues
---------------------------------

Issues from the coreboot bugtracker: <https://ticket.coreboot.org/>
* To be filled in immediately before the release by the release team



coreboot Links and Contact Information
--------------------------------------

* Main Web site: <https://www.coreboot.org>
* Downloads: <https://coreboot.org/downloads.html>
* Source control: <https://review.coreboot.org>
* Documentation: <https://doc.coreboot.org>
* Issue tracker: <https://ticket.coreboot.org/projects/coreboot>
* Donations: <https://coreboot.org/donate.html>
